pub struct QueryTimings {
pub query_id: String,
pub phases: Vec<(String, Duration)>,
pub total: Duration,
/* private fields */
}Expand description
Collected timing phases for a single query.
Fields
query_id: Stringphases: Vec<(String, Duration)>total: DurationImplementations
Sourceimpl QueryTimings
impl QueryTimings
Sourcepub fn begin(query_id: impl Into<String>) -> Option<Self>
pub fn begin(query_id: impl Into<String>) -> Option<Self>
Create a new QueryTimings and start the total wall-clock timer.
Returns None when timing is disabled (zero overhead path).
Sourcepub fn begin_from_sql(sql: &str) -> Option<Self>
pub fn begin_from_sql(sql: &str) -> Option<Self>
Create a QueryTimings using the first [MAX_QUERY_ID_LENGTH] chars
of the SQL string as the query identifier.
Sourcepub fn start_phase(&self) -> Instant
pub fn start_phase(&self) -> Instant
Start timing a named phase. Returns the Instant to pass to [end_phase].
Sourcepub fn end_phase(&mut self, name: &str, since: Instant)
pub fn end_phase(&mut self, name: &str, since: Instant)
Record the elapsed time for a phase started with [start_phase].
Sourcepub fn add_accumulated_phase(&mut self, name: &str, duration: Duration)
pub fn add_accumulated_phase(&mut self, name: &str, duration: Duration)
Record a pre-computed duration for a phase that was accumulated across multiple iterations (e.g., per-table I/O totals).